Arkindex base Worker
====================

An easy to use Python 3 high level API client, to build ML tasks.


## Create a new worker using our template

```
pip install --user cookiecutter
cookiecutter git@gitlab.com:arkindex/base-worker.git
```
